@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -30,6 +25,8 @@ class CMultiSelect extends CTag {
 	 */
 	const SEARCH_METHOD = 'multiselect.get';
 
+	const FILTER_PRESELECT_ACCEPT_ID = 'id';
+
 	/**
 	 * @var array
 	 */
@@ -60,20 +57,11 @@ class CMultiSelect extends CTag {
 			$this->setAttribute('aria-disabled', 'true');
 		}
 
-		// Autocomplete url.
-		$url = (new CUrl('jsrpc.php'))
-			->setArgument('type', PAGE_TYPE_TEXT_RETURN_JSON)
-			->setArgument('method', static::SEARCH_METHOD)
-			->setArgument('object_name', $options['object_name']);
-
-		if (array_key_exists('objectOptions', $options)) {
-			foreach ($options['objectOptions'] as $option_name => $option_value) {
-				$url->setArgument($option_name, $option_value);
-			}
+		if (array_key_exists('readonly', $options) && $options['readonly']) {
+			$this->setAttribute('aria-readonly', 'true');
 		}
 
-		$params = [
-			'url' => $url->getUrl(),
+		$this->params = [
 			'name' => $options['name'],
 			'labels' => [
 				'No matches found' => _('No matches found'),
@@ -84,35 +72,52 @@ class CMultiSelect extends CTag {
 			]
 		];
 
+		if (array_key_exists('object_name', $options)) {
+			// Autocomplete url.
+			$url = (new CUrl('jsrpc.php'))
+				->setArgument('type', PAGE_TYPE_TEXT_RETURN_JSON)
+				->setArgument('method', static::SEARCH_METHOD)
+				->setArgument('object_name', $options['object_name']);
+
+			if (array_key_exists('objectOptions', $options)) {
+				foreach ($options['objectOptions'] as $option_name => $option_value) {
+					$url->setArgument($option_name, $option_value);
+				}
+			}
+
+			$this->params['url'] = $url->getUrl();
+		}
+
 		if (array_key_exists('multiselect_id', $options)) {
-			$params['multiselect_id'] = $options['multiselect_id'];
+			$this->params['multiselect_id'] = $options['multiselect_id'];
 		}
 
 		if (array_key_exists('data', $options)) {
-			$params['data'] = zbx_cleanHashes($options['data']);
+			$this->params['data'] = zbx_cleanHashes($options['data']);
 		}
 
-		foreach (['defaultValue', 'disabled', 'selectedLimit', 'addNew', 'styles', 'placeholder'] as $option) {
+		foreach (['defaultValue', 'disabled', 'selectedLimit', 'addNew', 'styles', 'placeholder', 'hidden', 'readonly']
+				as $option) {
 			if (array_key_exists($option, $options)) {
-				$params[$option] = $options[$option];
+				$this->params[$option] = $options[$option];
 			}
 		}
 
 		if (array_key_exists('autosuggest', $options)
 				&& array_key_exists('filter_preselect', $options['autosuggest'])) {
-			$params['autosuggest']['filter_preselect'] = $options['autosuggest']['filter_preselect'];
+			$this->params['autosuggest']['filter_preselect'] = $options['autosuggest']['filter_preselect'];
 		}
 
 		if (array_key_exists('custom_select', $options)) {
-			$params['custom_select'] = $options['custom_select'];
+			$this->params['custom_select'] = $options['custom_select'];
 		}
 		elseif (array_key_exists('popup', $options)) {
 			if (array_key_exists('filter_preselect', $options['popup'])) {
-				$params['popup']['filter_preselect'] = $options['popup']['filter_preselect'];
+				$this->params['popup']['filter_preselect'] = $options['popup']['filter_preselect'];
 			}
 
 			if (array_key_exists('parameters', $options['popup'])) {
-				$params['popup']['parameters'] = $options['popup']['parameters'];
+				$this->params['popup']['parameters'] = $options['popup']['parameters'];
 
 				$excludeids = array_key_exists('excludeids', $options['popup']['parameters'])
 					? $options['popup']['parameters']['excludeids']
@@ -123,12 +128,12 @@ class CMultiSelect extends CTag {
 					: []);
 
 				if ($excludeids) {
-					$params['excludeids'] = $excludeids;
+					$this->params['excludeids'] = $excludeids;
 				}
 			}
 		}
 
-		$this->params = $params;
+		$this->setAttribute('data-params', $this->params);
 
 		if (!array_key_exists('add_post_js', $options) || $options['add_post_js']) {
 			zbx_add_post_js($this->getPostJS());
@@ -140,8 +145,12 @@ class CMultiSelect extends CTag {
 		return $this;
 	}
 
+	public function getParams(): array {
+		return $this->params;
+	}
+
 	public function getPostJS() {
-		return 'jQuery("#'.$this->getAttribute('id').'").multiSelect('.json_encode($this->params).');';
+		return 'jQuery("#'.$this->getAttribute('id').'").multiSelect();';
 	}
 
 	/**
@@ -153,7 +162,8 @@ class CMultiSelect extends CTag {
 	 */
 	protected function mapOptions(array $options) {
 		$valid_fields = ['name', 'object_name', 'multiselect_id', 'multiple', 'disabled', 'default_value', 'data',
-			'add_new', 'add_post_js', 'styles', 'popup', 'custom_select', 'placeholder', 'autosuggest'
+			'add_new', 'add_post_js', 'styles', 'popup', 'custom_select', 'placeholder', 'autosuggest', 'hidden',
+			'readonly'
 		];
 
 		foreach ($options as $field => $value) {
@@ -168,12 +178,14 @@ class CMultiSelect extends CTag {
 			'object_name' => 'object_name',
 			'multiselect_id' => 'multiselect_id',
 			'disabled' => 'disabled',
+			'hidden' => 'hidden',
 			'default_value' => 'defaultValue',
 			'data' => 'data',
 			'add_new' => 'addNew',
 			'add_post_js' => 'add_post_js',
 			'styles' => 'styles',
-			'placeholder' => 'placeholder'
+			'placeholder' => 'placeholder',
+			'readonly' => 'readonly'
 		];
 
 		foreach ($mappings as $new_field => $old_field) {
@@ -247,7 +259,7 @@ class CMultiSelect extends CTag {
 					'with_items', 'with_simple_graph_items', 'with_simple_graph_item_prototypes', 'with_triggers',
 					'value_types', 'excludeids', 'disableids', 'enrich_parent_groups', 'with_monitored_items',
 					'with_httptests', 'user_type', 'disable_selected', 'hostids', 'with_inherited', 'context',
-					'enabled_only', 'group_status', 'exclude_provisioned'
+					'enabled_only', 'group_status', 'hide_host_filter', 'resolve_macros', 'exclude_provisioned'
 				];
 
 				foreach ($parameters as $field => $value) {
@@ -279,6 +291,10 @@ class CMultiSelect extends CTag {
 					$autocomplete_parameters['hostid'] = (string) $parameters['hostid'];
 				}
 
+				if (array_key_exists('hide_host_filter', $parameters)) {
+					$popup_parameters['hide_host_filter'] = '1';
+				}
+
 				if (array_key_exists('groupid', $parameters) && $parameters['groupid'] > 0) {
 					$popup_parameters['groupid'] = (string) $parameters['groupid'];
 				}
@@ -413,6 +429,11 @@ class CMultiSelect extends CTag {
 					$autocomplete_parameters['group_status'] = $parameters['group_status'];
 				}
 
+				if (array_key_exists('resolve_macros', $parameters) && $parameters['resolve_macros']) {
+					$popup_parameters['resolve_macros'] = '1';
+					$autocomplete_parameters['resolve_macros'] = true;
+				}
+
 				if (array_key_exists('exclude_provisioned', $parameters) && $parameters['exclude_provisioned']) {
 					$popup_parameters['exclude_provisioned'] = 1;
 					$autocomplete_parameters['exclude_provisioned'] = 1;
@@ -431,7 +452,7 @@ class CMultiSelect extends CTag {
 		$is_valid = true;
 
 		foreach (array_keys($field) as $option) {
-			if (!in_array($option, ['id', 'submit_as', 'submit_parameters', 'multiple'])) {
+			if (!in_array($option, ['id', 'accept', 'submit_as', 'submit_parameters', 'multiple'])) {
 				error('unsupported option: '.$path.'[\''.$option.'\']');
 				$is_valid = false;
 			}
@@ -442,8 +463,12 @@ class CMultiSelect extends CTag {
 			$is_valid = false;
 		}
 
-		if (array_key_exists('submit_as', $field)
-				&& (!is_string($field['submit_as']) || $field['submit_as'] === '')) {
+		if (array_key_exists('accept', $field) && $field['accept'] !== self::FILTER_PRESELECT_ACCEPT_ID) {
+			error('invalid property: '.$path.'[\'accept\']');
+			$is_valid = false;
+		}
+
+		if (!array_key_exists('submit_as', $field) || !is_string($field['submit_as']) || $field['submit_as'] === '') {
 			error('invalid property: '.$path.'[\'submit_as\']');
 			$is_valid = false;
 		}
