@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 class CValidationRule {
@@ -77,8 +72,7 @@ class CValidationRule {
 									&& !$this->parseArray($buffer, $pos, $rule)
 									&& !$this->parseFlags($buffer, $pos, $rule)
 									&& !$this->parseBool($buffer, $pos, $rule)
-									&& !$this->parseCuid($buffer, $pos, $rule)
-									&& !$this->parsePassword($buffer, $pos, $rule)) {
+									&& !$this->parseCuid($buffer, $pos, $rule)) {
 								// incorrect validation rule
 								break 3;
 							}
@@ -162,22 +156,6 @@ class CValidationRule {
 		return true;
 	}
 
-	/**
-	 * password
-	 *
-	 * 'password' => true
-	 */
-	private function parsePassword($buffer, &$pos, &$rules) {
-		if (strncmp(substr($buffer, $pos), 'password', 8) != 0) {
-			return false;
-		}
-
-		$pos += 8;
-		$rules['password'] = true;
-
-		return true;
-	}
-
 	/**
 	 * range_time
 	 *
