@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -74,7 +69,7 @@ function make_decoration($haystack, $needle, $class = null) {
 	return $result;
 }
 
-function prepareUrlParam($value, $name = null) {
+function prepareUrlParam($value, $name = null): string {
 	if (is_array($value)) {
 		$result = '';
 
@@ -92,26 +87,22 @@ function prepareUrlParam($value, $name = null) {
 /**
  * Get ready for url params.
  *
- * @param mixed  $param				param name or array with data depend from $getFromRequest
- * @param bool   $getFromRequest	detect data source - input array or $_REQUEST variable
- * @param string $name				if $_REQUEST variable is used this variable not used
- *
- * @return string
+ * @param mixed       $param           Param name or array with data depends from $getFromRequest.
+ * @param bool        $getFromRequest  Detect data source - input array or $_REQUEST variable.
+ * @param string|null $name            If $_REQUEST variable is used this variable not used.
  */
-function url_param($param, $getFromRequest = true, $name = null) {
+function url_param($param, bool $getFromRequest = true, string $name = null): string {
 	if (is_array($param)) {
 		if ($getFromRequest) {
 			fatal_error(_('URL parameter cannot be array.'));
 		}
 	}
-	else {
-		if (is_null($name)) {
-			if (!$getFromRequest) {
-				fatal_error(_('URL parameter name is empty.'));
-			}
-
-			$name = $param;
+	elseif ($name === null) {
+		if (!$getFromRequest) {
+			fatal_error(_('URL parameter name is empty.'));
 		}
+
+		$name = $param;
 	}
 
 	if ($getFromRequest) {
@@ -124,7 +115,7 @@ function url_param($param, $getFromRequest = true, $name = null) {
 	return isset($value) ? prepareUrlParam($value, $name) : '';
 }
 
-function url_params(array $params) {
+function url_params(array $params): string {
 	$result = '';
 
 	foreach ($params as $param) {
@@ -134,7 +125,7 @@ function url_params(array $params) {
 	return $result;
 }
 
-function BR() {
+function BR(): CTag {
 	return new CTag('br');
 }
 
@@ -166,22 +157,18 @@ function RARR() {
 	return new CHtmlEntity('&rArr;');
 }
 
-function ZWSPACE() {
-	return new CHtmlEntity('&#8203;');
-}
-
-function get_icon($type, $params = []) {
+function get_icon($type, $params = []): ?CSimpleButton {
 	switch ($type) {
 		case 'favorite':
 			if (CFavorite::exists($params['fav'], $params['elid'], $params['elname'])) {
-				$icon = (new CRedirectButton(NBSP(), null))
-					->addClass(ZBX_STYLE_BTN_REMOVE_FAV)
+				$icon = (new CSimpleButton())
+					->addClass(ZBX_ICON_STAR_FILLED)
 					->setTitle(_('Remove from favorites'))
 					->onClick('rm4favorites("'.$params['elname'].'", "'.$params['elid'].'");');
 			}
 			else {
-				$icon = (new CRedirectButton(NBSP(), null))
-					->addClass(ZBX_STYLE_BTN_ADD_FAV)
+				$icon = (new CSimpleButton())
+					->addClass(ZBX_ICON_STAR)
 					->setTitle(_('Add to favorites'))
 					->onClick('add2favorites("'.$params['elname'].'", "'.$params['elid'].'");');
 			}
@@ -191,40 +178,44 @@ function get_icon($type, $params = []) {
 
 		case 'kioskmode':
 			if ($params['mode'] == ZBX_LAYOUT_KIOSKMODE) {
-				$icon = (new CButton(null, NBSP()))
-					->setTitle(_('Normal view'))
-					->setAttribute('data-layout-mode', ZBX_LAYOUT_NORMAL)
+				$icon = (new CSimpleButton())
 					->addClass(ZBX_LAYOUT_MODE)
+					->addClass(ZBX_ICON_MINIMIZE)
 					->addClass(ZBX_STYLE_BTN_DASHBOARD_NORMAL)
-					->addClass(ZBX_STYLE_BTN_MIN);
+					->setTitle(_('Normal view'))
+					->setAttribute('data-layout-mode', ZBX_LAYOUT_NORMAL);
 			}
 			else {
-				$icon = (new CButton(null, NBSP()))
-					->setTitle(_('Kiosk mode'))
-					->setAttribute('data-layout-mode', ZBX_LAYOUT_KIOSKMODE)
+				$icon = (new CSimpleButton())
 					->addClass(ZBX_LAYOUT_MODE)
-					->addClass(ZBX_STYLE_BTN_KIOSK);
+					->addClass(ZBX_ICON_FULLSCREEN)
+					->addClass(ZBX_STYLE_BTN_KIOSK)
+					->setTitle(_('Kiosk mode'))
+					->setAttribute('data-layout-mode', ZBX_LAYOUT_KIOSKMODE);
 			}
 
 			return $icon;
 	}
+
+	return null;
 }
 
 /**
  * Get host/template configuration navigation.
  *
- * @param string  $current_element
- * @param int     $hostid
- * @param int     $lld_ruleid
+ * @param string $current_element
+ * @param int    $hostid
+ * @param int    $lld_ruleid
  *
- * @return CList|null
+ * @throws Exception
  */
-function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
+function getHostNavigation(string $current_element, $hostid, $lld_ruleid = 0): ?CList {
 	$options = [
 		'output' => [
 			'hostid', 'status', 'name', 'maintenance_status', 'flags', 'active_available'
 		],
-		'selectHostDiscovery' => ['ts_delete'],
+		'selectHostDiscovery' => ['status', 'ts_delete', 'ts_disable', 'disable_source'],
+		'selectDiscoveryRule' => ['lifetime_type', 'enabled_lifetime_type'],
 		'selectInterfaces' => ['type', 'useip', 'ip', 'dns', 'port', 'version', 'details', 'available', 'error'],
 		'hostids' => [$hostid],
 		'editable' => true
@@ -302,7 +293,9 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 
 	if ($is_template) {
 		$template = new CSpan(
-			new CLink($db_host['name'], 'templates.php?form=update&templateid='.$db_host['templateid'])
+			(new CLink($db_host['name']))
+				->setAttribute('data-templateid', $db_host['templateid'])
+				->onClick('view.editTemplate(event, this.dataset.templateid);')
 		);
 
 		if ($current_element === '') {
@@ -310,7 +303,7 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 		}
 
 		$list->addItem(new CBreadcrumbs([
-			new CSpan(new CLink(_('All templates'), new CUrl('templates.php'))),
+			new CSpan(new CLink(_('All templates'), (new CUrl('zabbix.php'))->setArgument('action', 'template.list'))),
 			$template
 		]));
 
@@ -339,10 +332,9 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 				(new CUrl('zabbix.php'))
 					->setArgument('action', 'host.edit')
 					->setArgument('hostid', $db_host['hostid'])
-				)
-			)
-			->setAttribute('data-hostid', $db_host['hostid'])
-			->onClick('view.editHost(event, this.dataset.hostid);')
+			))
+				->setAttribute('data-hostid', $db_host['hostid'])
+				->onClick('view.editHost(event, this.dataset.hostid);')
 		);
 
 		if ($current_element === '') {
@@ -356,8 +348,17 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 			->addItem($status)
 			->addItem(getHostAvailabilityTable($db_host['interfaces'], $db_host['has_passive_checks']));
 
-		if ($db_host['flags'] == ZBX_FLAG_DISCOVERY_CREATED && $db_host['hostDiscovery']['ts_delete'] != 0) {
-			$info_icons = [getHostLifetimeIndicator(time(), $db_host['hostDiscovery']['ts_delete'])];
+		$disable_source = $db_host['status'] == HOST_STATUS_NOT_MONITORED && $db_host['hostDiscovery']
+			? $db_host['hostDiscovery']['disable_source']
+			: '';
+
+		if ($db_host['flags'] == ZBX_FLAG_DISCOVERY_CREATED
+				&& $db_host['hostDiscovery']['status'] == ZBX_LLD_STATUS_LOST) {
+			$info_icons = [getLldLostEntityIndicator(time(), $db_host['hostDiscovery']['ts_delete'],
+				$db_host['hostDiscovery']['ts_disable'], $disable_source,
+				$db_host['status'] == HOST_STATUS_NOT_MONITORED, _('host')
+			)];
+
 			$list->addItem(makeInformationList($info_icons));
 		}
 	}
@@ -375,14 +376,15 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 		// items
 		$items = new CSpan([
 			new CLink(_('Items'),
-				(new CUrl('items.php'))
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'item.list')
 					->setArgument('filter_set', '1')
 					->setArgument('filter_hostids', [$db_host['hostid']])
 					->setArgument('context', $context)
 			),
 			CViewHelper::showNum($db_host['items'])
 		]);
-		if ($current_element == 'items') {
+		if ($current_element === 'items') {
 			$items->addClass(ZBX_STYLE_SELECTED);
 		}
 		$content_menu->addItem($items);
@@ -390,14 +392,15 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 		// triggers
 		$triggers = new CSpan([
 			new CLink(_('Triggers'),
-				(new CUrl('triggers.php'))
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'trigger.list')
 					->setArgument('filter_set', '1')
 					->setArgument('filter_hostids', [$db_host['hostid']])
 					->setArgument('context', $context)
 			),
 			CViewHelper::showNum($db_host['triggers'])
 		]);
-		if ($current_element == 'triggers') {
+		if ($current_element === 'triggers') {
 			$triggers->addClass(ZBX_STYLE_SELECTED);
 		}
 		$content_menu->addItem($triggers);
@@ -411,7 +414,7 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 			),
 			CViewHelper::showNum($db_host['graphs'])
 		]);
-		if ($current_element == 'graphs') {
+		if ($current_element === 'graphs') {
 			$graphs->addClass(ZBX_STYLE_SELECTED);
 		}
 		$content_menu->addItem($graphs);
@@ -426,7 +429,7 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 				),
 				CViewHelper::showNum($db_host['dashboards'])
 			]);
-			if ($current_element == 'dashboards') {
+			if ($current_element === 'dashboards') {
 				$dashboards->addClass(ZBX_STYLE_SELECTED);
 			}
 			$content_menu->addItem($dashboards);
@@ -441,7 +444,7 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 			),
 			CViewHelper::showNum($db_host['discoveries'])
 		]);
-		if ($current_element == 'discoveries') {
+		if ($current_element === 'discoveries') {
 			$lld_rules->addClass(ZBX_STYLE_SELECTED);
 		}
 		$content_menu->addItem($lld_rules);
@@ -456,7 +459,7 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 			),
 			CViewHelper::showNum($db_host['httpTests'])
 		]);
-		if ($current_element == 'web') {
+		if ($current_element === 'web') {
 			$http_tests->addClass(ZBX_STYLE_SELECTED);
 		}
 		$content_menu->addItem($http_tests);
@@ -472,7 +475,7 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 			)
 		);
 
-		if ($current_element == 'discoveries') {
+		if ($current_element === 'discoveries') {
 			$discovery_rule->addClass(ZBX_STYLE_SELECTED);
 		}
 
@@ -489,13 +492,14 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 		// item prototypes
 		$item_prototypes = new CSpan([
 			new CLink(_('Item prototypes'),
-				(new CUrl('disc_prototypes.php'))
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'item.prototype.list')
 					->setArgument('parent_discoveryid', $db_discovery_rule['itemid'])
 					->setArgument('context', $context)
 			),
 			CViewHelper::showNum($db_discovery_rule['items'])
 		]);
-		if ($current_element == 'items') {
+		if ($current_element === 'items') {
 			$item_prototypes->addClass(ZBX_STYLE_SELECTED);
 		}
 		$content_menu->addItem($item_prototypes);
@@ -503,13 +507,14 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 		// trigger prototypes
 		$trigger_prototypes = new CSpan([
 			new CLink(_('Trigger prototypes'),
-				(new CUrl('trigger_prototypes.php'))
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'trigger.prototype.list')
 					->setArgument('parent_discoveryid', $db_discovery_rule['itemid'])
 					->setArgument('context', $context)
 			),
 			CViewHelper::showNum($db_discovery_rule['triggers'])
 		]);
-		if ($current_element == 'triggers') {
+		if ($current_element === 'triggers') {
 			$trigger_prototypes->addClass(ZBX_STYLE_SELECTED);
 		}
 		$content_menu->addItem($trigger_prototypes);
@@ -538,7 +543,7 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 				),
 				CViewHelper::showNum($db_discovery_rule['hostPrototypes'])
 			]);
-			if ($current_element == 'hosts') {
+			if ($current_element === 'hosts') {
 				$host_prototypes->addClass(ZBX_STYLE_SELECTED);
 			}
 			$content_menu->addItem($host_prototypes);
@@ -553,13 +558,11 @@ function getHostNavigation($current_element, $hostid, $lld_ruleid = 0) {
 /**
  * Get map navigation.
  *
- * @param int    $sysmapid      Used as value for sysmaid in map link generation.
+ * @param int    $sysmapid      Used as value for sysmapid in map link generation.
  * @param string $name          Used as label for map link generation.
  * @param int    $severity_min  Used as value for severity_min in map link generation.
- *
- * @return CList
  */
-function getSysmapNavigation($sysmapid, $name, $severity_min) {
+function getSysmapNavigation($sysmapid, $name, $severity_min): CList {
 	$list = (new CList())->addItem(new CBreadcrumbs([
 		(new CSpan())->addItem(new CLink(_('All maps'), new CUrl('sysmaps.php'))),
 		(new CSpan())
@@ -597,14 +600,12 @@ function getSysmapNavigation($sysmapid, $name, $severity_min) {
 /**
  * Renders a form footer with the given buttons.
  *
- * @param CButtonInterface 		$main_button	main button that will be displayed on the left
- * @param CButtonInterface[] 	$other_buttons
- *
- * @return CDiv
+ * @param CButtonInterface|null $main_button  Main button that will be displayed on the left.
+ * @param CButtonInterface[]    $other_buttons
  *
  * @throws InvalidArgumentException	if an element of $other_buttons contain something other than CButtonInterface
  */
-function makeFormFooter(CButtonInterface $main_button = null, array $other_buttons = []) {
+function makeFormFooter(CButtonInterface $main_button = null, array $other_buttons = []): CList {
 	foreach ($other_buttons as $other_button) {
 		$other_button->addClass(ZBX_STYLE_BTN_ALT);
 	}
@@ -627,7 +628,7 @@ function makeFormFooter(CButtonInterface $main_button = null, array $other_butto
  * Create HTML helper element for host interfaces availability.
  *
  * @param array $host_interfaces
- * @param bool  $passive_checks
+ * @param bool $passive_checks
  *
  * @return CHostAvailability
  */
@@ -658,24 +659,21 @@ function getHostAvailabilityTable(array $host_interfaces, bool $passive_checks =
 /**
  * Returns the discovered host group lifetime indicator.
  *
- * @param string $current_time	current Unix timestamp
- * @param array  $ts_delete		deletion timestamp of the host group
+ * @param int $current_time  Current Unix timestamp.
+ * @param int $ts_delete     Deletion timestamp of the host group.
  *
- * @return CLink
+ * @throws Exception
  */
-function getHostGroupLifetimeIndicator($current_time, $ts_delete) {
+function getHostGroupLifetimeIndicator(int $current_time, int $ts_delete): CSimpleButton {
 	// Check if the element should've been deleted in the past.
 	if ($current_time > $ts_delete) {
-		$warning = _(
-			'The host group is not discovered anymore and will be deleted the next time discovery rule is processed.'
+		$warning = _s('The %1$s is not discovered anymore and %2$s.', _('host group'),
+			_('will be deleted the next time discovery rule is processed')
 		);
 	}
 	else {
-		$warning = _s(
-			'The host group is not discovered anymore and will be deleted in %1$s (on %2$s at %3$s).',
-			zbx_date2age($current_time, $ts_delete),
-			zbx_date2str(DATE_FORMAT, $ts_delete),
-			zbx_date2str(TIME_FORMAT, $ts_delete)
+		$warning = _s('The %1$s is not discovered anymore and %2$s.', _('host group'),
+			_s('will be deleted in %1$s', zbx_date2age($current_time, $ts_delete))
 		);
 	}
 
@@ -683,114 +681,128 @@ function getHostGroupLifetimeIndicator($current_time, $ts_delete) {
 }
 
 /**
- * Returns the discovered host lifetime indicator.
+ * Returns the indicator for lost LLD entity.
  *
- * @param string $current_time	current Unix timestamp
- * @param array  $ts_delete		deletion timestamp of the host
+ * @param int     $current_time    Current Unix timestamp.
+ * @param int     $ts_delete       Deletion timestamp of the entity.
+ * @param int     $ts_disable      Disabling timestamp of the entity.
+ * @param string  $disable_source  Indicator whether entity was disabled by an LLD rule or manually.
+ * @param boolean $disabled        Indicator whether entity is disabled.
+ * @param string  $entity          Type of entity.
  *
- * @return CLink
+ * @throws Exception
  */
-function getHostLifetimeIndicator($current_time, $ts_delete) {
-	// Check if the element should've been deleted in the past.
-	if ($current_time > $ts_delete) {
-		$warning = _(
-			'The host is not discovered anymore and will be deleted the next time discovery rule is processed.'
+function getLldLostEntityIndicator(int $current_time, int $ts_delete, int $ts_disable, string $disable_source,
+		bool $disabled, string $entity): ?CSimpleButton {
+	$warning = '';
+
+	if ($disable_source == ZBX_DISABLE_SOURCE_LLD) {
+		if ($ts_delete > 0 && $current_time < $ts_delete) {
+			$warning = _s('The %1$s is not discovered anymore and %2$s, %3$s.', $entity, _('has been disabled'),
+				_s('will be deleted in %1$s', zbx_date2age($current_time, $ts_delete))
+			);
+		}
+		elseif ($ts_delete == 0) {
+			$warning = _s('The %1$s is not discovered anymore and %2$s, %3$s.', $entity, _('has been disabled'),
+				_('will not be deleted')
+			);
+		}
+		elseif ($current_time > $ts_delete) {
+			$warning = _s('The %1$s is not discovered anymore and %2$s, %3$s.', $entity, _('has been disabled'),
+				_('will be deleted the next time discovery rule is processed')
+			);
+		}
+	}
+	elseif ($disabled && $disable_source == ZBX_DISABLE_DEFAULT && $ts_delete > 0) {
+		$warning = _s('The %1$s is not discovered anymore and %2$s, %3$s.', $entity, _('has been manually disabled'),
+			_('will not be deleted')
 		);
 	}
-	else {
-		$warning = _s(
-			'The host is not discovered anymore and will be deleted in %1$s (on %2$s at %3$s).',
-			zbx_date2age($current_time, $ts_delete),
-			zbx_date2str(DATE_FORMAT, $ts_delete),
-			zbx_date2str(TIME_FORMAT, $ts_delete)
-		);
+	elseif (!$disabled && $ts_delete > 0) {
+		$delete_msg = _s('will be deleted in %1$s', zbx_date2age($current_time, $ts_delete));
+
+		switch (true) {
+			case $current_time > $ts_delete:
+				$warning = _s('The %1$s is not discovered anymore and %2$s.', $entity,
+					_('will be deleted the next time discovery rule is processed')
+				);
+				break;
+
+			case $ts_disable == 0:
+				$warning = _s('The %1$s is not discovered anymore and %2$s, %3$s.', $entity,
+					_s('will not be disabled'), $delete_msg
+				);
+				break;
+
+			case $ts_disable > 0 && $ts_disable > $current_time:
+				$warning = _s('The %1$s is not discovered anymore and %2$s, %3$s.', $entity,
+					_s('will be disabled in %1$s', zbx_date2age($current_time, $ts_disable)), $delete_msg
+				);
+				break;
+
+			case $ts_disable != 0 && $current_time > $ts_disable:
+				$warning = _s('The %1$s is not discovered anymore and %2$s, %3$s.', $entity,
+					_('will be disabled the next time discovery rule is processed'), $delete_msg
+				);
+				break;
+		}
+	}
+	elseif (!$disabled && $ts_delete == 0) {
+		$delete_msg = _('will not be deleted');
+
+		switch (true) {
+			case $ts_disable != 0 && $current_time > $ts_disable:
+				$warning = _s('The %1$s is not discovered anymore and %2$s, %3$s.', $entity,
+					_('will be disabled the next time discovery rule is processed'), $delete_msg
+				);
+				break;
+
+			case $ts_disable > 0:
+				$warning = _s('The %1$s is not discovered anymore and %2$s, %3$s.', $entity,
+					_s('will be disabled in %1$s', zbx_date2age($current_time, $ts_disable)), $delete_msg
+				);
+				break;
+
+			case $ts_disable == 0:
+				$warning = _s('The %1$s is not discovered anymore and %2$s, %3$s.', $entity,
+					_('will not be disabled'), $delete_msg
+				);
+				break;
+		}
 	}
 
-	return makeWarningIcon($warning);
+	return $warning === '' ? null : makeWarningIcon($warning);
 }
 
 /**
  * Returns the discovered graph lifetime indicator.
  *
- * @param string $current_time	current Unix timestamp
- * @param array  $ts_delete		deletion timestamp of the graph
+ * @param int $current_time   Current Unix timestamp.
+ * @param int $ts_delete      Deletion timestamp of the graph.
  *
- * @return CLink
+ * @throws Exception
  */
-function getGraphLifetimeIndicator($current_time, $ts_delete) {
-	// Check if the element should've been deleted in the past.
-	if ($current_time > $ts_delete) {
-		$warning = _(
-			'The graph is not discovered anymore and will be deleted the next time discovery rule is processed.'
+function getGraphLifetimeIndicator(int $current_time, int $ts_delete): ?CSimpleButton {
+	if ($ts_delete == 0) {
+		$warning = _s('The %1$s is not discovered anymore and %2$s.', _('graph'),
+			_('will not be deleted')
+		);
+	}
+	elseif ($current_time > $ts_delete && $ts_delete != 0) {
+		$warning = _s('The %1$s is not discovered anymore and %2$s.', _('graph'),
+			_('will be deleted the next time discovery rule is processed')
 		);
 	}
 	else {
-		$warning = _s(
-			'The graph is not discovered anymore and will be deleted in %1$s (on %2$s at %3$s).',
-			zbx_date2age($current_time, $ts_delete),
-			zbx_date2str(DATE_FORMAT, $ts_delete),
-			zbx_date2str(TIME_FORMAT, $ts_delete)
+		$warning = _s('The %1$s is not discovered anymore and %2$s.', _('graph'),
+			_s('will be deleted in %1$s', zbx_date2age($current_time, $ts_delete))
 		);
 	}
 
 	return makeWarningIcon($warning);
 }
 
-/**
- * Returns the discovered trigger lifetime indicator.
- *
- * @param string $current_time	current Unix timestamp
- * @param array  $ts_delete		deletion timestamp of the trigger
- *
- * @return CLink
- */
-function getTriggerLifetimeIndicator($current_time, $ts_delete) {
-	// Check if the element should've been deleted in the past.
-	if ($current_time > $ts_delete) {
-		$warning = _(
-			'The trigger is not discovered anymore and will be deleted the next time discovery rule is processed.'
-		);
-	}
-	else {
-		$warning = _s(
-			'The trigger is not discovered anymore and will be deleted in %1$s (on %2$s at %3$s).',
-			zbx_date2age($current_time, $ts_delete),
-			zbx_date2str(DATE_FORMAT, $ts_delete),
-			zbx_date2str(TIME_FORMAT, $ts_delete)
-		);
-	}
-
-	return makeWarningIcon($warning);
-}
-
-/**
- * Returns the discovered item lifetime indicator.
- *
- * @param string $current_time	current Unix timestamp
- * @param array  $ts_delete		deletion timestamp of the item
- *
- * @return CLink
- */
-function getItemLifetimeIndicator($current_time, $ts_delete) {
-	// Check if the element should've been deleted in the past.
-	if ($current_time > $ts_delete) {
-		$warning = _(
-			'The item is not discovered anymore and will be deleted the next time discovery rule is processed.'
-		);
-	}
-	else {
-		$warning = _s(
-			'The item is not discovered anymore and will be deleted in %1$s (on %2$s at %3$s).',
-			zbx_date2age($current_time, $ts_delete),
-			zbx_date2str(DATE_FORMAT, $ts_delete),
-			zbx_date2str(TIME_FORMAT, $ts_delete)
-		);
-	}
-
-	return makeWarningIcon($warning);
-}
-
-function makeServerStatusOutput() {
+function makeServerStatusOutput(): CTag {
 	return (new CTag('output', true))
 		->setId('msg-global-footer')
 		->addClass(ZBX_STYLE_MSG_GLOBAL_FOOTER)
@@ -801,14 +813,12 @@ function makeServerStatusOutput() {
 * Make logo of the specified type.
 *
 * @param int $type  LOGO_TYPE_NORMAL | LOGO_TYPE_SIDEBAR | LOGO_TYPE_SIDEBAR_COMPACT.
-*
-* @return CTag
 */
-function makeLogo(int $type): ?CTag {
+function makeLogo(int $type): CTag {
 	static $zabbix_logo_classes = [
 		LOGO_TYPE_NORMAL => ZBX_STYLE_ZABBIX_LOGO,
-		LOGO_TYPE_SIDEBAR => ZBX_STYLE_ZABBIX_SIDEBAR_LOGO,
-		LOGO_TYPE_SIDEBAR_COMPACT => ZBX_STYLE_ZABBIX_SIDEBAR_LOGO_COMPACT
+		LOGO_TYPE_SIDEBAR => ZBX_STYLE_ZABBIX_LOGO_SIDEBAR,
+		LOGO_TYPE_SIDEBAR_COMPACT => ZBX_STYLE_ZABBIX_LOGO_SIDEBAR_COMPACT
 	];
 
 	$brand_logo = CBrandHelper::getLogo($type);
@@ -816,19 +826,14 @@ function makeLogo(int $type): ?CTag {
 	if ($brand_logo !== null) {
 		return (new CImg($brand_logo));
 	}
-	else {
-		return (new CDiv())->addClass($zabbix_logo_classes[$type]);
-	}
+
+	return (new CDiv())->addClass($zabbix_logo_classes[$type]);
 }
 
 /**
  * Renders a page footer.
- *
- * @param bool $with_version
- *
- * @return CDiv
  */
-function makePageFooter($with_version = true) {
+function makePageFooter(bool $with_version = true): CTag {
 	return (new CTag('footer', true, CBrandHelper::getFooterContent($with_version)))
 		->setAttribute('role', 'contentinfo');
 }
@@ -836,6 +841,8 @@ function makePageFooter($with_version = true) {
 /**
  * Get drop-down submenu item list for the User settings section.
  *
+ * @throws Exception
+ *
  * @return array  Menu definition for CHtmlPage::setTitleSubmenu.
  */
 function getUserSettingsSubmenu(): array {
@@ -866,7 +873,7 @@ function getUserSettingsSubmenu(): array {
  *
  * @return array  Menu definition for CHtmlPage::setTitleSubmenu.
  */
-function getAdministrationGeneralSubmenu() {
+function getAdministrationGeneralSubmenu(): array {
 	$gui_url = (new CUrl('zabbix.php'))
 		->setArgument('action', 'gui.edit')
 		->getUrl();
@@ -875,6 +882,10 @@ function getAdministrationGeneralSubmenu() {
 		->setArgument('action', 'autoreg.edit')
 		->getUrl();
 
+	$timeouts_url = (new CUrl('zabbix.php'))
+		->setArgument('action', 'timeouts.edit')
+		->getUrl();
+
 	$image_url = (new CUrl('zabbix.php'))
 		->setArgument('action', 'image.list')
 		->getUrl();
@@ -912,6 +923,7 @@ function getAdministrationGeneralSubmenu() {
 			'items' => array_filter([
 				$gui_url            => _('GUI'),
 				$autoreg_url        => _('Autoregistration'),
+				$timeouts_url       => _('Timeouts'),
 				$image_url          => _('Images'),
 				$iconmap_url        => _('Icon mapping'),
 				$regex_url          => _('Regular expressions'),
@@ -936,30 +948,14 @@ function makeInformationList($info_icons) {
 	return $info_icons ? (new CDiv($info_icons))->addClass(ZBX_STYLE_REL_CONTAINER) : '';
 }
 
-/**
- * Renders an information icon like green [i] with message.
- *
- * @param string $message
- *
- * @return CLink
- */
-function makeInformationIcon($message) {
-	return (new CLink())
-		->addClass(ZBX_STYLE_ICON_INFO)
-		->addClass(ZBX_STYLE_STATUS_GREEN)
-		->setHint($message, ZBX_STYLE_HINTBOX_WRAP);
-}
-
 /**
  * Renders an icon for host in maintenance.
  *
- * @param int    $type         Type of the maintenance.
- * @param string $name         Name of the maintenance.
- * @param string $description  Description of the maintenance.
- *
- * @return CLink
+ * @param int|string $type         Type of the maintenance.
+ * @param string     $name         Name of the maintenance.
+ * @param string     $description  Description of the maintenance.
  */
-function makeMaintenanceIcon($type, $name, $description) {
+function makeMaintenanceIcon($type, string $name, string $description): CButtonIcon {
 	$hint = $name.' ['.($type
 		? _('Maintenance without data collection')
 		: _('Maintenance with data collection')).']';
@@ -968,8 +964,9 @@ function makeMaintenanceIcon($type, $name, $description) {
 		$hint .= "\n".$description;
 	}
 
-	return (new CLink())
-		->addClass(ZBX_STYLE_ICON_MAINTENANCE)
+	return (new CButtonIcon(ZBX_ICON_WRENCH_ALT_SMALL))
+		->addClass(ZBX_STYLE_COLOR_WARNING)
+		->addClass(ZBX_STYLE_NO_INDENT)
 		->setHint($hint);
 }
 
@@ -977,14 +974,14 @@ function makeMaintenanceIcon($type, $name, $description) {
  * Renders an icon for suppressed problem.
  *
  * @param array  $icon_data
- * @param string $icon_data[]['suppress_until']    Time until the problem is suppressed.
- * @param string $icon_data[]['maintenance_name']  Name of the maintenance.
- * @param string $icon_data[]['username']          User who created manual suppression.
+ *        string $icon_data[]['suppress_until']    Time until the problem is suppressed.
+ *        string $icon_data[]['maintenance_name']  Name of the maintenance.
+ *        string $icon_data[]['username']          User who created manual suppression.
  * @param bool   $blink                            Add 'blink' CSS class for jqBlink.
  *
- * @return CLink
+ * @throws Exception
  */
-function makeSuppressedProblemIcon(array $icon_data, bool $blink = false) {
+function makeSuppressedProblemIcon(array $icon_data, bool $blink = false): CSimpleButton {
 	$suppress_until_values = array_column($icon_data, 'suppress_until');
 
 	if (in_array(ZBX_PROBLEM_SUPPRESS_TIME_INDEFINITE, $suppress_until_values)) {
@@ -1006,132 +1003,80 @@ function makeSuppressedProblemIcon(array $icon_data, bool $blink = false) {
 		if (array_key_exists('maintenance_name', $suppression)) {
 			$maintenance_names[] = $suppression['maintenance_name'];
 		}
-		else {
+		elseif (array_key_exists('username', $suppression)) {
 			$username = $suppression['username'];
 		}
 	}
 
-	$maintenances = implode(',', $maintenance_names);
+	$maintenances = implode(', ', $maintenance_names);
 
-	return (new CSimpleButton())
-		->addClass(ZBX_STYLE_ACTION_ICON_SUPPRESS)
-		->addClass($blink ? 'blink' : null)
+	return (new CButtonIcon(ZBX_ICON_EYE_OFF))
+		->addClass(ZBX_STYLE_COLOR_ICON)
+		->addClass($blink ? 'js-blink' : null)
 		->setHint(
 			_s('Suppressed till: %1$s', $suppressed_till).
-			"\n".
-			($username !== '' ? _s('Manually by: %1$s', $username)."\n" : '').
-			($maintenances !== '' ? _s('Maintenance: %1$s', $maintenances)."\n" : '')
+			($username !== '' ? "\n"._s('Manually by: %1$s', $username) : '').
+			($maintenances !== '' ? "\n"._s('Maintenance: %1$s', $maintenances) : '')
 		);
 }
 
-/**
- * Renders an action icon.
- *
- * @param array  $icon_data
- * @param string $icon_data[icon]    Icon style.
- * @param array  $icon_data[hint]    Hintbox content (optional).
- * @param bool   $icon_data[button]  Use button element (optional).
- * @param int    $icon_data[num]     Number displayed over the icon (optional).
- *
- * @return CTag  Returns CSpan or CButton depending on boolean $icon_data['button'] parameter
- */
-function makeActionIcon(array $icon_data): CTag {
-	if (array_key_exists('button', $icon_data) && $icon_data['button']) {
-		$icon = (new CButton(null))->addClass($icon_data['icon']);
-	}
-	else {
-		$icon = (new CSpan())->addClass($icon_data['icon']);
-	}
-
-	if (array_key_exists('num', $icon_data)) {
-		if ($icon_data['num'] > 99) {
-			$icon_data['num'] = '99+';
-		}
-		$icon->setAttribute('data-count', $icon_data['num']);
-	}
-
-	if (array_key_exists('hint', $icon_data)) {
-		$icon
-			->addClass(ZBX_STYLE_CURSOR_POINTER)
-			->setHint($icon_data['hint'], '', true, 'max-width: '.ZBX_ACTIONS_POPUP_MAX_WIDTH.'px;');
-	}
-	elseif (array_key_exists('title', $icon_data)) {
-		$icon->setTitle($icon_data['title']);
-	}
-
-	if (array_key_exists('style', $icon_data)) {
-		$icon->addStyle($icon_data['style']);
-	}
-
-	if (array_key_exists('aria-label', $icon_data)) {
-		$icon
-			->addItem($icon_data['aria-label'])
-			->addClass(ZBX_STYLE_INLINE_SR_ONLY);
-	}
-
-	return $icon;
-}
-
-/**
- * Renders an icon for a description.
- *
- * @param string $description
- *
- * @return CLink
- */
-function makeDescriptionIcon($description) {
-	return (new CLink())
-		->addClass(ZBX_STYLE_ICON_DESCRIPTION)
-		->setHint(zbx_str2links($description), ZBX_STYLE_HINTBOX_WRAP);
-}
-
-/**
- * Renders an error icon like red [i] with error message
- *
- * @param string $error
- *
- * @return CLink
- */
-function makeErrorIcon($error) {
-	return (new CLink())
-		->addClass(ZBX_STYLE_ICON_INFO)
-		->addClass(ZBX_STYLE_STATUS_RED)
-		->setHint($error, ZBX_STYLE_HINTBOX_WRAP." ".ZBX_STYLE_RED);
-}
-
 /**
  * Renders an icon with question mark and text in hint.
  *
  * @param string|array|CTag $help_text
- *
- * @return CLink
  */
-function makeHelpIcon($help_text): CLink {
-	return (new CLink())
-		->addClass(ZBX_STYLE_ICON_HELP_HINT)
+function makeHelpIcon($help_text): CSimpleButton {
+	return (new CButtonIcon(ZBX_ICON_HELP_FILLED_SMALL))
+		->setSmall()
 		->setHint($help_text, ZBX_STYLE_HINTBOX_WRAP);
 }
 
 /**
- * Renders a warning icon like yellow [i] with error message
- *
- * @param string $error
- *
- * @return CLink
+ * Renders an icon for a description.
  */
-function makeWarningIcon($error) {
-	return (new CLink())
-		->addClass(ZBX_STYLE_ICON_INFO)
-		->addClass(ZBX_STYLE_STATUS_YELLOW)
-		->setHint($error, ZBX_STYLE_HINTBOX_WRAP);
+function makeDescriptionIcon(string $description): CButtonIcon {
+	return (new CButtonIcon(ZBX_ICON_ALERT_WITH_CONTENT))
+		->setAttribute('data-content', '?')
+		->setHint(zbx_str2links($description), ZBX_STYLE_HINTBOX_WRAP);
+}
+
+/**
+ * Renders an information icon like green [i] with message.
+ *
+ * @param string|array|CTag $message
+ */
+function makeInformationIcon($message): CButtonIcon {
+	return (new CButtonIcon(ZBX_ICON_I_POSITIVE))
+		->setSmall()
+		->setHint($message, ZBX_STYLE_HINTBOX_WRAP);
+}
+
+/**
+ * Renders a warning icon like yellow [i] with error message.
+ *
+ * @param string|array|CTag $warning
+ */
+function makeWarningIcon($warning): CButtonIcon {
+	return (new CButtonIcon(ZBX_ICON_I_WARNING))
+		->setSmall()
+		->setHint($warning, ZBX_STYLE_HINTBOX_WRAP);
+}
+
+/**
+ * Renders an error icon like red [i] with error message.
+ *
+ * @param string|array|CTag $error
+ */
+function makeErrorIcon($error): CButtonIcon {
+	return (new CButtonIcon(ZBX_ICON_I_NEGATIVE))
+		->setSmall()
+		->setHint($error, ZBX_STYLE_HINTBOX_WRAP.' '.ZBX_STYLE_RED);
 }
 
 /**
  * Returns css for trigger severity backgrounds.
- *
- * @return string
  */
-function getTriggerSeverityCss() {
+function getTriggerSeverityCss(): string {
 	$css = '';
 
 	$severities = [
@@ -1159,10 +1104,8 @@ function getTriggerSeverityCss() {
 
 /**
  * Returns css for trigger status colors, if those are customized.
- *
- * @return string
  */
-function getTriggerStatusCss() {
+function getTriggerStatusCss(): string {
 	$css = '';
 
 	if (CSettingsHelper::getPublic(CSettingsHelper::CUSTOM_COLOR) == EVENT_CUSTOM_COLOR_ENABLED) {
